@@ -56,19 +56,21 @@ except:
     _brlAPIAvailable = False
     _brlAPIRunning = False
 
+from . import settings
+
 try:
     # This can fail due to gtk not being available.  We want to
     # be able to recover from that if possible.  The main driver
     # for this is to allow "orca --text-setup" to work even if
     # the desktop is not running.
     #
-    import brlmon
+    from . import brlmon
 except:
-    pass
-import debug
-import eventsynthesizer
-import orca_state
-import settings
+    settings.enableBrailleMonitor = False
+
+from . import debug
+from . import eventsynthesizer
+from . import orca_state
 
 # Right now, the orca autogen.sh/configure needs a priori knowledge of
 # where the liblouis tables are.  When running autogen.sh/configure,
@@ -79,7 +81,7 @@ import settings
 # liblouis bindings can give us the tablesdir information at runtime
 # http://code.google.com/p/liblouis/issues/detail?id=9]]
 #
-from orca_platform import tablesdir
+from .orca_platform import tablesdir
 if louis and not tablesdir:
     debug.println(debug.LEVEL_SEVERE,
                   "Contraction tables for liblouis cannot be found.")
@@ -91,7 +93,7 @@ if louis and not tablesdir:
                   "not be available.")
     louis = None
     
-from orca_i18n import _                          # for gettext support
+from .orca_i18n import _                          # for gettext support
 
 # The braille monitor
 #
@@ -607,11 +609,20 @@ class Text(Region):
             self.caretOffset = 0
             self.lineOffset = 0
 
-        string = string.decode("UTF-8")
+        try:
+            string = string.decode("UTF-8")
+        except UnicodeEncodeError:
+            pass
         if label:
-            label = label.decode("UTF-8")
+            try:
+                label = label.decode("UTF-8")
+            except UnicodeEncodeError:
+                pass
         if eol:
-            eol = eol.decode("UTF-8")
+            try:
+                eol = eol.decode("UTF-8")
+            except UnicodeEncodeError:
+                pass
 
         try:
             endOffset = endOffset - self.lineOffset
@@ -665,7 +676,10 @@ class Text(Region):
         [string, caretOffset, lineOffset] = \
                  orca_state.activeScript.getTextLineAtCaret(self.accessible,
                                                             self.startOffset)
-        string = string.decode("UTF-8")
+        try:
+            string = string.decode("UTF-8")
+        except:
+            pass
 
         cursorOffset = min(caretOffset - lineOffset, len(string))
 
@@ -753,7 +767,7 @@ class Text(Region):
             while n < nLinks:
                 link = hyperText.getLink(n)
                 if self.lineOffset <= link.startIndex:
-                    for i in xrange(link.startIndex, link.endIndex):
+                    for i in range(link.startIndex, link.endIndex):
                         try:
                             regionMask[i] |= linkIndicator
                         except:
@@ -781,7 +795,7 @@ class Text(Region):
                 if mask != settings.TEXT_ATTR_BRAILLE_NONE:
                     maskStart = max(startOffset - self.lineOffset, 0)
                     maskEnd = min(endOffset - self.lineOffset, stringLength)
-                    for i in xrange(maskStart, maskEnd):
+                    for i in range(maskStart, maskEnd):
                         regionMask[i] |= attrIndicator
 
         if selIndicator:
@@ -789,7 +803,7 @@ class Text(Region):
             for startOffset, endOffset in selections:
                 maskStart = max(startOffset - self.lineOffset, 0)
                 maskEnd = min(endOffset - self.lineOffset, stringLength)
-                for i in xrange(maskStart, maskEnd):
+                for i in range(maskStart, maskEnd):
                     regionMask[i] |= selIndicator
 
         if self.contracted:
@@ -1436,13 +1450,18 @@ def refresh(panToCursor=True,
 
     if settings.enableBrailleMonitor:
         if not _monitor:
-            _monitor = brlmon.BrlMon(_displaySize[0])
-            _monitor.show_all()
+            try:
+                _monitor = brlmon.BrlMon(_displaySize[0])
+                _monitor.show_all()
+            except:
+                debug.println(debug.LEVEL_WARNING, "brlmon failed")
+                _monitor = None
         if attributeMask:
             subMask = attributeMask[startPos:endPos]
         else:
             subMask = None
-        _monitor.writeText(cursorCell, substring, subMask)
+        if _monitor:
+            _monitor.writeText(cursorCell, substring, subMask)
     elif _monitor:
         _monitor.destroy()
         _monitor = None
