@@ -30,10 +30,10 @@ import pyatspi
 import orca.orca as orca
 import orca.debug as debug
 import orca.scripts.default as default
+import orca.settings_manager as settings_manager
 import orca.orca_state as orca_state
 import orca.speech as speech
 import orca.scripts.toolkits.Gecko as Gecko
-
 from orca.orca_i18n import _
 
 from .formatting import Formatting
@@ -41,7 +41,7 @@ from .speech_generator import SpeechGenerator
 from .script_utilities import Utilities
 from . import script_settings
 
-_settingsManager = getattr(orca, '_settingsManager')
+_settingsManager = settings_manager.getManager()
 
 ########################################################################
 #                                                                      #
