@@ -1,7 +1,7 @@
 # Orca
 #
 # Copyright (C) 2010 Joanmarie Diggs
-# Copyright (C) 2011 Igalia, S.L.
+# Copyright (C) 2011-2012 Igalia, S.L.
 #
 # Author: Joanmarie Diggs <jdiggs@igalia.com>
 #
@@ -24,20 +24,18 @@ __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2010 Joanmarie Diggs" \
-                "Copyright (c) 2011 Igalia, S.L."
+                "Copyright (c) 2011-2012 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
 
 import orca.keynames as keynames
-import orca.orca as orca
-import orca.rolenames as rolenames
 import orca.settings as settings
+import orca.settings_manager as settings_manager
 import orca.speech_generator as speech_generator
-
 from orca.orca_i18n import _
 
-_settingsManager = getattr(orca, '_settingsManager')
+_settingsManager = settings_manager.getManager()
 
 ########################################################################
 #                                                                      #
@@ -81,6 +79,24 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
+    def __generateHeadingRole(self, obj):
+        result = []
+        role = pyatspi.ROLE_HEADING
+        level = self._script.utilities.headingLevel(obj)
+        if level:
+            # Translators: the %(level)d is in reference to a heading
+            # level in HTML (e.g., For <h3>, the level is 3)
+            # and the %(role)s is in reference to a previously
+            # translated rolename for the heading.
+            #
+            result.append(_("%(role)s level %(level)d") % {
+                    'role': self.getLocalizedRoleName(obj, role),
+                    'level': level})
+        else:
+            result.append(self.getLocalizedRoleName(obj, role))
+
+        return result
+
     def _generateRoleName(self, obj, **args):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
@@ -105,23 +121,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 link = self._script.utilities.ancestorWithRole(
                     obj, [pyatspi.ROLE_LINK], [pyatspi.ROLE_DOCUMENT_FRAME])
                 if link:
-                    result.append(rolenames.getSpeechForRoleName(link))
-
-            if role == pyatspi.ROLE_HEADING:
-                level = self._script.utilities.headingLevel(obj)
-                if level:
-                    # Translators: the %(level)d is in reference to a heading
-                    # level in HTML (e.g., For <h3>, the level is 3)
-                    # and the %(role)s is in reference to a previously
-                    # translated rolename for the heading.
-                    #
-                    result.append(_("%(role)s level %(level)d") % {
-                        'role': rolenames.getSpeechForRoleName(obj, role),
-                        'level': level})
-                else:
-                    result.append(rolenames.getSpeechForRoleName(obj, role))
+                    result.append(self.getLocalizedRoleName(link))
+            elif role == pyatspi.ROLE_HEADING:
+                result.extend(self.__generateHeadingRole(obj))
             else:
-                result.append(rolenames.getSpeechForRoleName(obj, role))
+                result.append(self.getLocalizedRoleName(obj, role))
+                if obj.parent and obj.parent.getRole() == pyatspi.ROLE_HEADING:
+                    result.extend(self.__generateHeadingRole(obj.parent))
 
             if result:
                 result.extend(acss)
@@ -132,7 +138,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 # want to indicate that.
                 #
                 acss = self.voice(speech_generator.HYPERLINK)
-                result.append(rolenames.getSpeechForRoleName(obj[0]))
+                result.append(self.getLocalizedRoleName(obj[0]))
                 result.extend(acss)
 
         return result
