@@ -32,14 +32,14 @@ log = logging.getLogger("speech")
 import re
 import time
 
-import chnames
-import debug
-import orca_state
-import settings
-import sound
-import speech_generator
+from . import chnames
+from . import debug
+from . import orca_state
+from . import settings
+from . import sound
+from . import speech_generator
 
-from acss import ACSS
+from .acss import ACSS
 
 # The speech server to use for all speech operations.
 #
@@ -169,7 +169,7 @@ def _speak(text, acss, interrupt):
 
     logLine = "SPEECH OUTPUT: '" + text + "'"
     extraDebug = ""
-    if acss in settings.voices.values():
+    if acss in list(settings.voices.values()):
         for key in settings.voices:
             if acss == settings.voices[key]:
                 if key != settings.DEFAULT_VOICE:
@@ -405,17 +405,17 @@ def testNoSettingsInit():
     speak("this is normal")
 
 def test():
-    import speechserver
+    from . import speechserver
     factories = getSpeechServerFactories()
     for factory in factories:
-        print factory.__name__
+        print(factory.__name__)
         servers = factory.SpeechServer.getSpeechServers()
         for server in servers:
             try:
-                print "    ", server.getInfo()
+                print("    ", server.getInfo())
                 for family in server.getVoiceFamilies():
                     name = family[speechserver.VoiceFamily.NAME]
-                    print "      ", name
+                    print("      ", name)
                     acss = ACSS({ACSS.FAMILY : family})
                     server.speak(name, acss)
                     server.speak("testing")
